require_relative 'player'
require_relative 'game_turn'
require 'csv'

module StudioGame
  class Game
    attr_accessor :name

    def initialize(name)
      @name = name.capitalize
      @players = []
    end

    def add_player(player)
      @players << player
    end

    def high_score_entry(player)
      "#{player.name.ljust(15, '.')} #{player.score}"
    end

    def load_players(file_to_load)
      CSV.foreach(file_to_load) do |row|
        player = Player.new(row[0], Integer(row[1]))
        add_player(player)
      end
    end

    def save_high_scores(file_to_save)
      File.open(file_to_save, "w") do |file|
        file.puts "\n#{@name} High Scores"
        sorted_players = @players.sort

        sorted_players.each do |player|
          file.puts high_score_entry(player)
         end
      end
    end

    def play(rounds_number)
      puts "The game #{@name} has been started with #{@players.length} players"
      treasures = TreasureTrove::TREASURES 
      puts "There are #{treasures.length} treasures"

      treasures.each do |treasure|
        puts "a #{treasure.name} worth #{treasure.point} points"
      end


      1.upto(rounds_number) do |number|
        puts "\nRound #{number} Started"
        @players.each do |player|
          GameTurn.take_turn(player)
        end
        if block_given?
          break if yield
        end
        puts @players
      end
    end

    def print_name_and_health(player)
      puts "#{player.name} (#{player.health})"
    end

    def total_points
      points = 0
      @players.each do |player|
        points += player.points
      end
      points
    end

    def print_stats
      puts "\n#{@name} statistics"

      puts "\nTotal treasures points found in the game"
      puts "#{total_points} total points"

      puts "\nTotal each player grand points"
      @players.each do |player|
        puts "\n#{player.name} #{player.points} total points"
        player.each_found_treasure do |treasure|
          puts "#{treasure.name} with the total of #{treasure.point}"

        end
      end

      strong, wimpy = @players.partition do |player|
        player.strong?
      end

      puts "\n#{strong.length} strong players"
      strong.each do |player|
        print_name_and_health(player)
      end

      puts "\n#{wimpy.length} wimpy players"
      wimpy.each do |player|
        print_name_and_health(player)
      end

      puts "\n#{@name} High Scores"
      sorted_players = @players.sort

      sorted_players.each do |player|
        puts high_score_entry(player)
      end
    end
  end
end


if __FILE__ == $0
  player = StudioGame::Player.new("johan")
  game = StudioGame::Game.new("sonic")
  game.add_player(player)
  game.play(1)
  puts player.score


end