require_relative 'treasure_trove'
require_relative 'playable'

module StudioGame
  class Player
    include Playable
    attr_accessor :name, :health

    def <=>(other_player)
      other_player.score <=> score
    end

    def initialize(name, health=100)
      @name = name.capitalize
      @health = health
      @found_treasures = Hash.new(0)
    end

    def self.from_csv(line)
      name, health = line.split(',')
      Player.new(name, Integer(health))
    end

    def found_treasure(treasure)
      @found_treasures[treasure.name] += treasure.point
      puts "#{@name} found #{treasure.name} worth #{treasure.point} points"
      puts "Found Treasures : #{@found_treasures}"
    end

    def each_found_treasure
      @found_treasures.each do |name, points|
        treasure = Treasure.new(name, points)
        yield treasure
      end
    end

    def points
      @found_treasures.values.reduce(:+)
    end

    def to_s
      "I am #{@name} with health: #{@health}, points: #{points} and score: #{score}"
    end

    def score
      @health + points
    end

  end
end

if __FILE__ == $0
  player = StudioGame::Player.new("alfian", 100)
  player.w00t
  player.blam
  player.found_treasure(Treasure.new(:excalibur, 100))
  player.found_treasure(Treasure.new(:excalibur, 100))
  puts player
  puts player.points


end


